# coding: utf-8

"""
AppFoundryApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class AppFoundryApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_appfoundry_platform_name_categories(self, platform_name, **kwargs):
        """
        Return a structured hierarchy of available listing categories
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_appfoundry_platform_name_categories(platform_name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str platform_name:  (required)
        :return: list[AppFoundryListingCategory]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['platform_name']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_appfoundry_platform_name_categories" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'platform_name' is set
        if ('platform_name' not in params) or (params['platform_name'] is None):
            raise ValueError("Missing the required parameter `platform_name` when calling `get_appfoundry_platform_name_categories`")


        resource_path = '/api/v2/appfoundry/{platformName}/categories'.replace('{format}', 'json')
        path_params = {}
        if 'platform_name' in params:
            path_params['platformName'] = params['platform_name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='list[AppFoundryListingCategory]',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_appfoundry_platform_name_category(self, platform_name, category_name, **kwargs):
        """
        Get listings that are part of the specified root category or a contained subcategory
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_appfoundry_platform_name_category(platform_name, category_name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str platform_name:  (required)
        :param str category_name: Name of category to request listings from (required)
        :param int page_size: The total page size requested
        :param int page_number: The page number requested
        :param str sort_by: variable name requested to sort by
        :param list[object] expand: variable name requested by expand list
        :param str next_page: next page token
        :param str previous_page: Previous page token
        :return: PagedListingEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['platform_name', 'category_name', 'page_size', 'page_number', 'sort_by', 'expand', 'next_page', 'previous_page']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_appfoundry_platform_name_category" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'platform_name' is set
        if ('platform_name' not in params) or (params['platform_name'] is None):
            raise ValueError("Missing the required parameter `platform_name` when calling `get_appfoundry_platform_name_category`")
        # verify the required parameter 'category_name' is set
        if ('category_name' not in params) or (params['category_name'] is None):
            raise ValueError("Missing the required parameter `category_name` when calling `get_appfoundry_platform_name_category`")


        resource_path = '/api/v2/appfoundry/{platformName}/categories/{categoryName}'.replace('{format}', 'json')
        path_params = {}
        if 'platform_name' in params:
            path_params['platformName'] = params['platform_name']
        if 'category_name' in params:
            path_params['categoryName'] = params['category_name']

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'previous_page' in params:
            query_params['previousPage'] = params['previous_page']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PagedListingEntity',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_appfoundry_platform_name_category_sub_category_name(self, platform_name, category_name, sub_category_name, **kwargs):
        """
        Get listings that are part of the specified subcategory
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_appfoundry_platform_name_category_sub_category_name(platform_name, category_name, sub_category_name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str platform_name:  (required)
        :param str category_name: Name of category to request listings from (required)
        :param str sub_category_name: Name of subcategory to request listings from (required)
        :param int page_size: The total page size requested
        :param int page_number: The page number requested
        :param str sort_by: variable name requested to sort by
        :param list[object] expand: variable name requested by expand list
        :param str next_page: next page token
        :param str previous_page: Previous page token
        :return: PagedListingEntity
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['platform_name', 'category_name', 'sub_category_name', 'page_size', 'page_number', 'sort_by', 'expand', 'next_page', 'previous_page']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_appfoundry_platform_name_category_sub_category_name" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'platform_name' is set
        if ('platform_name' not in params) or (params['platform_name'] is None):
            raise ValueError("Missing the required parameter `platform_name` when calling `get_appfoundry_platform_name_category_sub_category_name`")
        # verify the required parameter 'category_name' is set
        if ('category_name' not in params) or (params['category_name'] is None):
            raise ValueError("Missing the required parameter `category_name` when calling `get_appfoundry_platform_name_category_sub_category_name`")
        # verify the required parameter 'sub_category_name' is set
        if ('sub_category_name' not in params) or (params['sub_category_name'] is None):
            raise ValueError("Missing the required parameter `sub_category_name` when calling `get_appfoundry_platform_name_category_sub_category_name`")


        resource_path = '/api/v2/appfoundry/{platformName}/categories/{categoryName}/{subCategoryName}'.replace('{format}', 'json')
        path_params = {}
        if 'platform_name' in params:
            path_params['platformName'] = params['platform_name']
        if 'category_name' in params:
            path_params['categoryName'] = params['category_name']
        if 'sub_category_name' in params:
            path_params['subCategoryName'] = params['sub_category_name']

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_by' in params:
            query_params['sortBy'] = params['sort_by']
        if 'expand' in params:
            query_params['expand'] = params['expand']
        if 'next_page' in params:
            query_params['nextPage'] = params['next_page']
        if 'previous_page' in params:
            query_params['previousPage'] = params['previous_page']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='PagedListingEntity',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response
